OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Záložky",
    "You bookmarked \"%s\"" : "Pridali ste záložku „%s“",
    "%1$s bookmarked \"%2$s\"" : "%1$s ako záložka „%2$s“",
    "Someone bookmarked \"%s\"" : "Niekto pridal záložku „%s“",
    "You deleted \"%s\"" : "Odstránili ste „%s“",
    "%1$s deleted \"%2$s\"" : "%1$s odstránené \"%2$s\"",
    "Someone deleted \"%s\"" : "Niekto odstránil „%s“",
    "You created folder \"%s\"" : "Vytvorili ste priečinok „%s“",
    "%1$s created folder \"%2$s\"" : "%1$s vytvoril priečinok „%2$s“",
    "Someone created folder \"%s\"" : "Niekto vytvoril priečinok „%s“",
    "You moved folder \"%s\"" : "Premiestnili preičinok „%s“",
    "%1$s moved folder \"%2$s\"" : "%1$s premiestnil priečinok „%2$s“",
    "Someone moved folder \"%s\"" : "Niekto premiestnil priečinok „%s“",
    "You deleted folder \"%s\"" : "Odstránili ste priečinok „%s“",
    "%1$s deleted folder \"%2$s\"" : "%1$s odstránil priečinok „%2$s“",
    "Someone deleted folder \"%s\"" : "Niekto odstránil priečinok „%s“",
    "You shared folder \"%1$s\" with %2$s" : "Zdieľali ste priečinok „%1$s“ s %2$s",
    "You shared folder \"%s\" with someone" : "Zdieľali ste s niekym priečinok „%s“",
    "%1$s shared folder \"%2$s\" with you" : "%1$s zdieľal s vami priečinok „%2$s“",
    "Someone shared folder \"%s\" with you" : "Niekto s vami zdieľal priečinok „%s“",
    "You unshared folder \"%1$s\" with %2$s" : "Zrušili ste zdieľanie priečinka „%1$s“ s %2$s",
    "You unshared folder \"%s\" with someone" : "S niekym ste zrušili zdieľanie priečinka „%s“",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s s vami zrušil zdieľanie priečinka „%2$s“",
    "Someone unshared folder \"%s\" with you" : "Niekto s vami zrušil zdieľanie priečinka „%s“",
    "No file provided for import" : "Nie je k dispozícii žiadny súbor na import",
    "Bookmarks shared by %s" : "Záložky, ktoré zdieľa %s",
    "Frequent bookmarks" : "Časté záložky",
    "Recent bookmarks" : "Aktuálne záložky",
    "Bookmark" : "Záložka",
    "Bookmark deleted" : "Záložka zmazaná",
    "Bookmark created" : "Záložka vytvorená",
    "Bookmark moved" : "Záložka presunutá",
    "Bookmark updated" : "Záložka auktualizovaná",
    "Create bookmark" : "Vytvoriť záložku",
    "Takes a link and adds it to your collection of bookmarks." : "Zoberte odkaz a pridajte ho k vašim záložkám.",
    "Bookmarks Backups" : "Zálohy záložiek",
    "Enter new title" : "Zadajte nový nadpis",
    "Select bookmark" : "Vybrať záložku",
    "Details" : "Detaily",
    "Rename" : "Premenovať",
    "Copy link" : "Kopíruj odkaz",
    "Move" : "Presunúť",
    "Add to folders" : "Pridať do priečinkov",
    "Do you really want to delete this bookmark?" : "Naozaj chcete zmazať všetky svoje záložky?",
    "Link copied to clipboard" : "Odkaz bol skopírovaný do schránky",
    "Content pending" : "Čakajúci obsah",
    "This content is being downloaded for offline use. Please check back later." : "Tento obsah sa sťahuje na použitie v režime offline. Skúste to znova neskôr.",
    "Bookmarked {time} ago" : "Záložka vytvorená {time} dozadu",
    "Bookmarked on {date}" : "Záložka vytvorená {date}",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Záložky súborov na webe, ako sú fotografie alebo PDF, sa automaticky uložia do vašich súborov Nextcloud, takže ich stále nájdete, aj keď je odkaz offline.",
    "Searching in the current folder only." : "Hľadanie iba v aktuálnom adresár.",
    "Repeat search in all folders" : "Opakovať vyhľadávanie vo všetkých adresár",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Odkazy v záložkách sú pravidelne kontrolované a tu sú uvedené tie, ktoré nie sú dostupné.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Priečinky so záložkami môžete zdieľať s ostatnými. Všetky priečinky zdieľané s vami sú uvedené tu.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Jedna záložka môže byť vo viacerých priečinkoch naraz. Jej aktualizáciou sa aktualizujú všetky kópie. Všetky duplicitné záložky sú tu uvedené pre pohodlie.",
    "Open all selected" : "Otvoriť všetky vybraté",
    "Move selection" : "Presun výberu",
    "Edit tags of selection" : "Editovať šťítky vybraných",
    "Delete selection" : "Zmazať výberu",
    "Select all" : "Vybrať všetko",
    "Cancel selection" : "Zrušiť výber",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Vybraté {folders} priečinky a {bookmarks} záložky",
    "Do you really want to delete these items?" : "Naozaj chcete odstrániť tieto položky?",
    "Go back" : "Ísť späť",
    "Share folder" : "Sprístupniť priečinok",
    "Select one or more tags" : "Zvoliť jeden alebo viac štítkov",
    "New" : "Nový",
    "New bookmark" : "Nová záložka",
    "New folder" : "Nový priečinok",
    "Change to grid view" : "Prepnúť na zobrazenie v mriežke",
    "Change to list view" : "Prepnúť na zobrazenie v zozname",
    "Copy RSS Feed of current view" : "Skopírovať RSS kanál aktuálneho zobrazenia",
    "The RSS feed requires authentication with your Nextcloud credentials" : "Informačný kanál RSS vyžaduje autentizáciu pomocou vašich prihlasovacích údajov Nextcloud",
    "Search" : "Hľadať",
    "Empty trash bin" : "Vyprázdniť kôš",
    "Sort by created date" : "Zoradiť podľa dátumu vytvorenia",
    "Sort by last modified" : "Zoradiť podľa dátumu poslednej zmeny",
    "Sort by title" : "Zoradiť podľa nadpisu",
    "Sort by click count" : "Zoradiť podľa počtu kliknutí",
    "Sort by manual order" : "Zoradiť manuálne",
    "Sort by URL" : "Zoradiť podľa URL",
    "RSS feed copied" : "RSS kanál je skopírovaný",
    "Enter a link" : "Zadať link",
    "Enter a title" : "Zadať názov",
    "No bookmarks found" : "Žiadne záložky neboli nájdené",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} priečinky a {bookmarks} záložky",
    "Welcome to Bookmarks" : "Vitajte v Záložkách",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Táto aplikácia vám umožňuje spravovať odkazy na vaše obľúbené miesta na webe. Roztrieďte svoje záložky do priečinkov, označte ich štítkami a sprístupnite ich ostatným! Aplikácia pravidelne kontroluje dostupnosť všetkých vašich odkazov a zobrazuje nedostupné odkazy. Ak pridáte odkaz na súbor na webe, súbor sa automaticky stiahne do vašich Nextcloud Súborov. Môžete tiež importovať záložky exportované z iných služieb alebo priamo synchronizovať záložky zo všetkých svojich prehliadačov pomocou tejto aplikácie.",
    "Add a bookmark" : "Pridať záložku",
    "Import bookmarks" : "Importovať záložky",
    "Sync with your browser" : "Synchronizovať s vašim prehliadačom",
    "Select folder" : "Vybrať priečinok",
    "Enter folder title" : "Zadať názov priečinka",
    "Shared by {user}" : "Zdieľa {user}",
    "Rename folder" : "Premenovať priečinok",
    "Move folder" : "Presunúť priečinok",
    "Choose folder" : "Vyberte priečinok",
    "Submit" : "Odoslať",
    "Cancel" : "Zrušiť",
    "Deleting bookmarks" : "Mažem záložky",
    "Deleting selection" : "Maže sa výber",
    "Importing bookmarks" : "Importujem záložky",
    "Moving selection" : "Presúvam vybrané",
    "Adding selection to folders" : "Pridávam vybrané do priečinkov",
    "All bookmarks" : "Všetky záložky",
    "Recent" : "Nedávne",
    "Shared with you" : "Zdieľané s vami",
    "Files" : "Súbory",
    "Duplicates" : "Duplicity",
    "Broken links" : "Poškodené odkazy",
    "New tag" : "Nový štítok",
    "Search tags" : "Vyhľadať štítky",
    "Delete" : "Zmazať",
    "Untagged" : "Bez štítku",
    "{used} bookmarks of {available} available" : "{used} záložky z {available} dostupných",
    "No bookmarked files" : "Žiadne záložky súborov",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Záložky súborov, ako sú fotografie alebo PDF, sa automaticky uložia do vašich súborov Nextcloud, takže ich stále nájdete, aj keď je odkaz offline.",
    "Nothing found" : "Nič sa nenašlo",
    "Your search yielded no results in the current folder." : "Vaše vyhľadávanie neprinieslo žiadne výsledky v aktuálnom priečinku.",
    "No broken links" : "Žiadne poškodené odkazy",
    "No shared folders" : "Žiadne zdieľané priečinky",
    "No duplicated bookmarks" : "Žiadne duplikovanéq záložky",
    "You haven't deleted anything yet." : "Zatiaľ ste nič neodstránili.",
    "No bookmarks here" : "Žiadne záložky",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Pridajte záložky ručne alebo ich importujte z HTML súboru.",
    "Bookmarks settings" : "Nastavenia záložiek",
    "Import/Export" : "Import/Export",
    "Export bookmarks" : "Exportovať záložky",
    "Auto-archiving" : "Auto-archivácia",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "Aplikácia na záložky môže automaticky archivovať webový obsah odkazov, ktoré ste si uložili do záložiek.",
    "Enable archiving" : "Povoliť archivovanie",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Vložte cestu k priečinku kde sa budú ukladať súbory v záložkách.",
    "Auto-Backup" : "Auto-zálohovanie",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "Aplikácia na záložky môže automaticky zálohovať vaše záložky denne, aby sa zabránilo strate údajov pri synchronizácii záložiek medzi zariadeniami.",
    "Enable backups" : "Povoliť zálohovanie",
    "Enter the path of a folder in your Files where backups will be stored." : "Vložte cestu k priečinku kde sa budú ukladať zálohy.",
    "Client apps" : "Aplikácie klienta",
    "Also check out the collection of client apps that integrate with this app: " : "Pozrite si sadu klientskych aplikácií, ktoré sa integrujú do tejto aplikácie:",
    "Install web app" : "Inštalovať webovú aplikáciu",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Môžete si nainštalovať túto aplikáciu na domovskú obrazovku vašeho zariadenia pre rýchly prístup k vašim záložkám na vašom telefóne. Môžete jednoducho odstrániť aplikáciu z vašej domovskej obrazovky, ak sa vám to nebude páčiť.",
    "Install on home screen" : "Nainštalovať na domovskú obrazovku",
    "Bookmarklet" : "Záložky",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Potiahnite túto položku do záložiek prehliadača a kliknutím pridajte stránku do záložiek.",
    "Add to {instanceName}" : "Pridať do {instanceName}",
    "Need help?" : "Potrebujete pomoc?",
    "Archive path" : "Archivovať cestu",
    "Backup path" : "Cesta k zálohám",
    "Please select \"Add to home screen\" in your browser menu" : "Prosím vyberte \"Pridať na domovskú obrazovku\" v menu vašeho prehliadača",
    "Title" : "Názov",
    "Link" : "Odkaz",
    "Untitled folder" : "Priečinok bez názvu",
    "Root folder" : "Koreňový priečinok",
    "Tags" : "Štítky",
    "Select tags and create new ones" : "Vyberte štítky a vytvorte nové",
    "Notes" : "Poznámky",
    "Notes for this bookmark …" : "Poznámky pre túto záložku ...",
    "Archived file" : "Archivovaný súbor",
    "Download file" : "Stiahnuť súbor",
    "Open file location" : "Otvoriť umiestnenie súboru",
    "Created {time} ago" : "Vytvorené  {time} spätne",
    "Created on {date}" : "Vytvorené {date}",
    "Owner" : "Majiteľ",
    "Sharing" : "Zdieľanie",
    "Select a user or group" : "Vyberte používateľa alebo skupinu",
    "Share link" : "Sprístupniť odkaz",
    "Reading allowed" : "Čítanie povolené",
    "Copy RSS feed" : "Kopírovať RSS kanál",
    "Delete link" : "Zmazať odkaz",
    "Create public link" : "Vytvoriť verejný odkaz",
    "Resharing allowed" : "Opätovné zdieľanie je povolené",
    "Editing allowed" : "Úpravy povolené",
    "Allow editing" : "Povoliť úpravy",
    "Allow resharing" : "Povoliť zdieľanie ďalej",
    "Remove share" : "Odstrániť zdieľanie",
    "Link copied" : "Odkaz bol skopírovaný",
    "Privacy" : "Súkromie",
    "Enable accessing and collecting information from the web pages you add" : "Povoľte prístup a zhromažďovanie informácií z pridaných webových stránok",
    "Performance" : "Výkon",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "V inštalácii s veľkým počtom používateľov môže byť užitočné obmedziť počet záložiek v jednom účte.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Maximálny povolený počet záložiek na účet. (0 bez limitu; predvolená hodnota bez limitu)",
    "Previews" : "Náhľady",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Môžete sa bezplatne zaregistrovať na adrese screeenly.com alebo si nastaviť vlastný server.",
    "Screeenly API URL" : "Screenly API URL",
    "Screeenly API key" : "Screenly API kľúč",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "Kľúč k API služby ScreenshotMachine",
    "Webshot" : "Webshot",
    "Webshot API URL" : "URL API služby Webshot",
    "Pageres CLI" : "Pageres CLI",
    "Pageres ENV variables" : "Premennné prostredia Pageres",
    "Failed to save settings" : "Nepodarilo sa uložiť nastavenia",
    "Failed to load settings" : "Nepodarilo sa načítať nastavenia",
    "This URL is already bookmarked! Overwrite?" : "Táto webová adresa sa už v záložkách nachádza. Chcete ju prepísať?",
    "Enter bookmark title" : "Zadať názov záložky",
    "Enter bookmark URL" : "Zadajte URL záložky",
    "Folder" : "Priečinok",
    "Root Folder" : "Koreňový priečinok",
    "Save" : "Uložiť",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Prístup k sieti je v predvolenom nastavení zakázaný. Prejdite do nastavení správcu pre aplikáciu záložiek a povoľte načítanie ukážok a favikónov.",
    "What's new?" : "Čo je nové?",
    "What" : "Čo",
    "Failed to count unavailable bookmarks" : "Nepodarilo sa spočítať neprístupné záložky",
    "Failed to count archived bookmarks" : "Nepodarilo sa spočítať archivované záložky",
    "Failed to count duplicated bookmarks" : "Chyba pri spočítavaní duplikovaných záložiek",
    "Failed to load bookmark" : "Nepodarilo sa načítať záložku",
    "Failed to find existing bookmark" : "Nepodarilo sa nájsť existujúcu záložku",
    "Failed to create bookmark" : "Nepodarilo sa vytvoriť záložku",
    "Failed to save bookmark" : "Nepodarilo sa uložiť záložku",
    "Failed to move bookmark" : "Nepodarilo sa presunúť záložku",
    "Failed to copy bookmark" : "Chyba pri kopírovaní záložky",
    "Failed to delete bookmark" : "Nepodarilo sa zmazať záložky",
    "Failed to rename tag" : "Nepodarilo sa premenovať štítok",
    "Failed to load tags" : "Nepodarilo sa načítať štítky",
    "Failed to load folders" : "Nepodarilo sa načítať priečinky",
    "Failed to delete folder" : "Nepodarilo sa zmazať priečinok",
    "Failed to create folder" : "Nepodarilo sa vytvoriť priečinok",
    "Failed to fetch bookmarks." : "Nepodarilo sa načítať záložky",
    "Failed to store setting" : "Nepodarilo sa uložiť nastavenie",
    "Failed to load setting {key}" : "Nepodarilo sa načítať nastavenie {key}",
    "Failed to update share {shareId}" : "Nepodarilo sa aktualizovať zdieľanie {shareId}",
    "Failed to delete share {shareId}" : "Nepodarilo sa zmazať zdieľanie {shareId}.",
    "Create bookmarks for mentioned links" : "Vytvorte záložky pre uvedené odkazy",
    "No links found in this message" : "V tejto správe sa nenašli žiadne odkazy",
    "Bookmarks feed" : "Kanál záložiek"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
